==> arduino-esp8266-2.6.3.tgz: share/arduino/hardware/espressif/esp8266/variants/itead/pins_arduino.h <==
/*
  pins_arduino.h - Pin definition functions for Arduino
  Part of Arduino - http://www.arduino.cc/

  Copyright (c) 2007 David A. Mellis
  Modified for ESP8266 platform by Ivan Grokhotkov, 2014-2015.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General
  Public License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA  02111-1307  USA

  $Id: wiring.h 249 2007-02-03 16:52:51Z mellis $
*/

#ifndef Pins_Arduino_h
#define Pins_Arduino_h

#if defined(ARDUINO_SONOFF_SV)
#define PIN_WIRE_SCL (5)
static const uint8_t SCL = PIN_WIRE_SCL;
#endif

#if defined(ARDUINO_SONOFF_TH) || defined(ARDUINO_SONOFF_BASIC)
#define PIN_WIRE_SCL (14)
static const uint8_t SCL = PIN_WIRE_SCL;
#endif

#if defined(ARDUINO_SONOFF_TH) || defined(ARDUINO_SONOFF_SV)
#define PIN_WIRE_SDA (4)
static const uint8_t SDA = PIN_WIRE_SDA;
#endif

static const uint8_t BUILTIN_BUTTON = 0;
static const uint8_t BUILTIN_RELAY = 12;

#define BUTTON_BUILTIN (0)
#define LED_BUILTIN    (13)
#define RELAY_BUILTIN  (12)

#include "../generic/common.h"

#endif /* Pins_Arduino_h */

==> arduino-esp8266-3.0.2p5.tgz: share/arduino/hardware/espressif/esp8266/variants/itead/pins_arduino.h <==
/*
  pins_arduino.h - Pin definition functions for Arduino
  Part of Arduino - http://www.arduino.cc/

  Copyright (c) 2007 David A. Mellis
  Modified for ESP8266 platform by Ivan Grokhotkov, 2014-2015.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General
  Public License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA  02111-1307  USA

  $Id: wiring.h 249 2007-02-03 16:52:51Z mellis $
*/

#ifndef Pins_Arduino_h
#define Pins_Arduino_h

#if defined(ARDUINO_ESP8266_SONOFF_SV)
#define PIN_WIRE_SCL (5)
static const uint8_t SCL = PIN_WIRE_SCL;
#endif

#if defined(ARDUINO_ESP8266_SONOFF_TH) || defined(ARDUINO_ESP8266_SONOFF_BASIC)
#define PIN_WIRE_SCL (14)
static const uint8_t SCL = PIN_WIRE_SCL;
#endif

#if defined(ARDUINO_ESP8266_SONOFF_TH) || defined(ARDUINO_ESP8266_SONOFF_SV)
#define PIN_WIRE_SDA (4)
static const uint8_t SDA = PIN_WIRE_SDA;
#endif

static const uint8_t BUILTIN_BUTTON = 0;
static const uint8_t BUILTIN_RELAY = 12;

#define BUTTON_BUILTIN (0)
#define LED_BUILTIN    (13)
#define RELAY_BUILTIN  (12)

#include "../generic/common.h"

#endif /* Pins_Arduino_h */
